#!/usr/bin/env python3.8
# -*- coding: utf-8 -*-
"""{{ name.capitalize() }} Package"""
from __future__ import annotations

import dataclasses
import inspect
import os

import typer

from bapy import ask, console, dbg, fm, fmt, ic, meta, PostDevelopCommand, PostInstallCommand

# <editor-fold desc="Bapy">
app = typer.Typer()
console = rich.console.Console()
dbg = devtools.debug
fm = icecream.IceCreamDebugger(prefix='').format
fmt = icecream.IceCreamDebugger(prefix='', includeContext=True).format
ic = icecream.IceCreamDebugger(prefix='', includeContext=True)
m = Meta()
os.environ["PYTHONWARNINGS"] = "ignore"
post = False


@app.command()
def meta() -> None:
    """
    Package Meta.

    Returns:
        None:
    """
    console.print(dataclasses.asdict(m))


@app.command()
def postcommand() -> None:
    """
    Post Install Command.

    Returns:
        None:
    """
    if post:
        if ask('Do you want to?'):
            console.print("Start installation!")
    else:
        pass
# </editor-fold>
__all__ = [item for item in globals() if not item.startswith('_') and not inspect.ismodule(globals().get(item))]
