include README.md

{% for item in include %}
recursive-include {{ item }} *
{% endfor %}
recursive-include tests *
recursive-exclude * __pycache__
recursive-exclude * *.py[co]

recursive-include docs *.rst conf.py Makefile make.bat *.jpg *.png *.gif
